<template>
  <div class="app-container">
    <el-card class="box-card" shadow="never">
      <div class="filter-container" style="margin-bottom: 10px">
        <my-search ref="searchBar" :items="items" @search="filterForm"></my-search>
      </div>
      <div class="title">物品统计表</div>
      <el-table
        v-loading="loading"
        :data="tableData"
        border
        style="width: 100%">
        <el-table-column
          align="center"
          prop="orgName"
          label="机构"
          min-width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="warehouseName"
          label="仓库/部门"
          min-width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="goodsCode"
          label="物品编码"
          width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="goodsTemplateName"
          label="物品名称"
          min-width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="baseGoodsModelsName"
          label="规格型号"
          min-width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="zaiKuNum"
          label="在库/在用数量"
          width="150">
        </el-table-column>

        <el-table-column
          align="center"
          prop="baoFeiNum"
          label="报废数"
          width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="diaoBoNum"
          label="调拨数"
          width="150">
        </el-table-column>
        <el-table-column
          align="center"
          prop="totalNum"
          label="总数量"
          width="150">
        </el-table-column>
      </el-table>
    </el-card>
  </div>
</template>

<script>
import {getGoodsStatistics} from '@/api/dashboard/goodsStatis.js'
import {formatDate} from "@/utils/DateFormatter";
import SettingIplatform from '@/utils/settingIplatform';

export default {
    data() {
      return {
        items: [
          {
            type: 'cascader',
            dataIndex: 'agencyId',
            label: '机构',
            placeholder: '请选择',
            defaultValue: '',
            options: [],
            cascader: [{key:'warehouseId',queryKey: 'agencyId'},{key:'goodsTemplateId',queryKey: 'agencyId'}],
            optionsConfig: { url: '/pc/fin/sys/tenant/select/tree_fin_tenant', props: null },
          },
          {
            type: 'select',
            dataIndex: 'baseWarehouseId',
            label: '仓库',
            placeholder: '请选择',
            defaultValue: '',
            options: [],
            optionsConfig: {
              label: 'warehouseName',
              value: 'id',
              url: SettingIplatform.apiBaseURL + '/pc/base/warehouse/select/tenant_warehouse'
            },
          },
          {
            type: 'select',
            dataIndex: 'goodsTemplateId',
            label: '物品名称',
            placeholder: '请输入',
            defaultValue: '',
            options: [],
            cascader: [{key:'categoryId',queryKey: 'goodsTemplatesId'}],
            optionsConfig: {
              label: 'goodsName',
              value: 'id',
              url: SettingIplatform.apiBaseURL + '/pc/base/goods/template/query/goodsTemplate',
            },
          },
          {
            type: 'select',
            dataIndex: 'baseGoodsModelsId',
            label: '规格型号',
            placeholder: '请选择',
            defaultValue: '',
            options: [],
            optionsConfig: {
              label: 'modelName',
              value: 'id',
              url: SettingIplatform.apiBaseURL + '/pc/base/goods/models/query/goodsModel'
            },
          },
          {
            type: 'select',
            dataIndex: 'costType',
            label: '类别',
            placeholder: '请选择',
            defaultValue: '',
            options: [{
              label: 'A',
              value: '1'},{
              label: 'B',
              value: '2'},{
              label: 'C',
              value: '3'}],

          },
        ],
        tableData: [],
        loading: true,
        params:{examYear: formatDate(new Date(),'yyyyMMdd')}
      }
    },
    mounted() {
      this.getTableData({})
    },
    methods: {
      filterForm(e) {
        this.params = e
        this.getTableData(e)
      },
      getTableData(e) {
        this.loading = true
        getGoodsStatistics(e).then(res => {
          this.tableData = res
          this.loading = false
        }).catch(() => {
          this.loading = false
        })
      }
    }
  }
</script>

<style scoped class="">
  .title{
    text-align: center;
    font-size: 18px;
    font-weight: bold;
    margin-bottom: 10px;
  }
</style>
